/*
 * directory.h
 *
 * Copyright (c) 1999  Oliver Fromme  <olli@fromme.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *     @(#)$Id: directory.h,v 1.2 1999/08/28 23:29:46 olli Exp $
 */

#ifndef _OPHOTO_DIRECTORY_H_
#define _OPHOTO_DIRECTORY_H_

static const char cvsid_directory_h[]
    = "@(#)$Id: directory.h,v 1.2 1999/08/28 23:29:46 olli Exp $";

#include <unistd.h>
#include <time.h>

#include "proto.h"

/*
 *   Structures for a directory and
 *   for a single directory entry.
 */

typedef struct {
	int num_entries;			/* number of entries */
	struct directory_entry_t *entries;	/* the actual entries */
} directory;

typedef struct directory_entry_t {
	char name[13];		/* name in UNIX-style format */
	unsigned char attr;	/* attribute flags, see below */
	time_t datetime;	/* time stamp of entry */
	off_t size;		/* file size*/
	directory *subdir;	/* pointer to subdir if applicable */
} directory_entry;

/*
 *   Attribute flags.
 */

#define ATTR_DIR	0x10	/* is a directory */

/*
 *   Function prototypes.
 */

char * parse_fatname (char *dst, char *fatname);
char * canon_path (char *src);
directory_entry * check_dir_entry (kodacon *kc, char *path, int dir_type);

#endif /* #ifndef _OPHOTO_DIRECTORY_H_ */

/* EOF */
